==> gnotepad+_1.2.1.orig.tar.gz: gnotepad+-1.2.1/acconfig.h <==
/* $Id: acconfig.h,v 1.7 2000/03/01 01:47:48 kahn Exp kahn $ */
/* general */
#define PACKAGE "gnp"
#define VERSION "x.x"

/* for runtime debugging */
#undef APP_DEBUG

/* if no runtime debugging, don't enable g_assert's */
#undef G_DISABLE_ASSERT

/* use gnome */
#undef USE_GNOME

/* load/unload unchanged docs */
#undef WANT_DOCUNLOAD

/* auto run in the background */
#undef WANT_BACKGROUND

/* splash screen */
#undef WANT_SPLASH

/* enable clipboard */
#undef USE_CLIPBOARD

/* enable unlimited undo/redo */
#undef USE_UNDOREDO

/* enable search and replace */
#undef USE_SEARCH

/* enable regular expression searches */
#undef USE_REGEX_SEARCH

/* enable opening recent documents */
#undef USE_RECENT

/* enable autosave */
#undef USE_AUTOSAVE

/* enable file backup */
#undef USE_BACKUP

/* enable inserting shell output */
#undef USE_SHELL_INSERT

/* enable toolbars */
#undef USE_TOOLBARS

/* enable doclist */
#undef USE_DOCLIST

/* enable fileinfo */
#undef USE_FILEINFO

/* enable winlist */
#undef USE_WINLIST

/* show random tips */
#undef USE_RANDOMTIPS

/* message box for logging */
#undef WANT_MSGBOX

/* include html tag insertion features */
#undef USE_HTMLTAGS

/* include source code control options */
#undef USE_SOURCE_CTRL

/* use enhanced file selection dialog */
#undef USE_ENHANCED_FSEL

/* for file locking */
#undef USE_FCNTL
#undef USE_FLOCK

/* for project/ide features (experimental) */
#undef WANT_PROJECT

/* use gtk-xmhtml to view html */
#undef USE_GTKXMHTML

/* use gtkhtml to view html */
#undef USE_GTKHTML

/* for gnotepad+ ! */
#define APP_GNP	1

/* i18n stuff */
#undef ENABLE_NLS
#undef HAVE_CATGETS
#undef HAVE_GETTEXT
#undef HAVE_LC_MESSAGES
#undef HAVE_STPCPY

==> gnotepad+-1.3.3.tar.gz: gnotepad+-1.3.3/acconfig.h <==
/* $Id: acconfig.h,v 1.8 2000/04/18 17:01:13 kahn Exp kahn $ */
/* general */
#define PACKAGE "gnp"
#define VERSION "x.x"

/* for runtime debugging */
#undef APP_DEBUG

/* if no runtime debugging, don't enable g_assert's */
#undef G_DISABLE_ASSERT

/* use gnome */
#undef USE_GNOME

/* use libglade */
#undef USE_LIBGLADE

/* load/unload unchanged docs */
#undef WANT_DOCUNLOAD

/* splash screen */
#undef WANT_SPLASH

/* session saving/restoring */
#undef WANT_SESSION

/* enable clipboard */
#undef USE_CLIPBOARD

/* enable unlimited undo/redo */
#undef USE_UNDOREDO

/* enable search and replace */
#undef USE_SEARCH

/* enable regular expression searches */
#undef USE_REGEX_SEARCH

/* enable opening recent documents */
#undef USE_RECENT

/* enable autosave */
#undef USE_AUTOSAVE

/* enable file backup */
#undef USE_BACKUP

/* enable inserting shell output */
#undef USE_SHELL_INSERT

/* enable toolbars */
#undef USE_TOOLBARS

/* enable doclist */
#undef USE_DOCLIST

/* enable fileinfo */
#undef USE_FILEINFO

/* enable winlist */
#undef USE_WINLIST

/* show random tips */
#undef USE_RANDOMTIPS

/* message box for logging */
#undef WANT_MSGBOX

/* include html tag insertion features */
#undef USE_HTMLTAGS

/* include source code control options */
#undef USE_SOURCE_CTRL

/* use enhanced file selection dialog */
#undef USE_ENHANCED_FSEL

/* for file locking */
#undef USE_FCNTL
#undef USE_FLOCK

/* for project/ide features (experimental) */
#undef WANT_PROJECT

/* use gtk-xmhtml to view html */
#undef USE_GTKXMHTML

/* use gtkhtml to view html */
#undef USE_GTKHTML

/* for gnotepad+ ! */
#define APP_GNP	1

/* i18n stuff */
#undef ENABLE_NLS
#undef HAVE_CATGETS
#undef HAVE_GETTEXT
#undef HAVE_LC_MESSAGES
#undef HAVE_STPCPY
